@@ -19,6 +19,8 @@ SECRET_ID_FILE = "/etc/fireinfo-id"
 INVALID_ID_STRINGS = (
 	"OEM", "O.E.M.", "o.e.m.",
 	"N/A", "n/a",
+	"12345", "54321", "202020",
+	"chassis",
 )
 
 class Singleton(type):
@@ -196,6 +198,9 @@ class System(object):
 		# Sort out all bogous or invalid strings from the list.
 		_ids = []
 		for id in ids:
+			if id is None:
+				continue
+
 			for i in INVALID_ID_STRINGS:
 				if i in id:
 					id = None
