@@ -254,7 +254,7 @@ read_harddisk_serial(char *device, char *serial) {
 	}
 
 	if (!ioctl(fd, HDIO_GET_IDENTITY, &hd)) {
-	    strncpy(serial, (const char *)hd.serial_no, sizeof(serial));
+	    strncpy(serial, (const char *)hd.serial_no, 20);
 	}
 }
 
